from scrumtools import base, data, error, github, trello

VERSION = (0, 0, 1)

get_version = lambda: '.'.join(map(str, VERSION))

__all__ = ['base', 'data', 'error', 'evaltool', 'github', 'trello']